==> hoteldruid-mod-pt_2.1.3-2.tar.gz: pt/inventario.php <==
<?php

switch ($messaggio) {

case "Inventario del magazzino":  		$messaggio = "Inventário do armazém"; break;
case "Nome bene":  				$messaggio = "Nome do bem"; break;
case "Quantità minima predefinita":  		$messaggio = "Quantidade mínima padrão"; break;
case "Quantità attuale":  			$messaggio = "Quantidade atual"; break;
case "Nuova quantità":  			$messaggio = "Nova quantidade"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Modifica le quantità attuali":  		$messaggio = "Alterar a quantidade atual"; break;
case "aggiungi":  				$messaggio = "adicionar"; break;
case "cancella":  				$messaggio = "apagar"; break;
case "Bene":  					$messaggio = "Bem"; break;
case "cancellato":  				$messaggio = "apagado"; break;
case "Quantità aggiornate":  			$messaggio = "Quantidade atualizada"; break;
case "Nuovo bene":  				$messaggio = "Novo bem"; break;
case "aggiunto":  				$messaggio = "adicionado"; break;
case "ricarica":  				$messaggio = "recarregar"; break;
case "Si è sicuri di voler eliminare il bene":	$messaggio = "Você tem certeza que quer apagar o bem"; break;
case "dall'inventario":  			$messaggio = "do inventário"; break;
case "del magazzino":  				$messaggio = "do armazém"; break;
case "SI":  					$messaggio = "SIM"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "Bene ricaricato":  			$messaggio = "Bem recarregado"; break;
case "Ricarica il bene":  			$messaggio = "recarregar o bem"; break;
case "da":  					$messaggio = "do"; break;
case "magazzino":  				$messaggio = "armazém"; break;
case "Nessun posto da cui ricaricare":  	$messaggio = "Não há lugar para recarregar"; break;
case "mancanti":  				$messaggio = "em falta"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "richiesto_per registrare entrata":  	$messaggio = "pedido_para registrar a entrada"; break;
case "si":  					$messaggio = "sim"; break;
case "no":  					$messaggio = "não"; break;
case "Aggiungi":  				$messaggio = "Adicionar"; break;
case "Sottrai":  				$messaggio = "Subtrair"; break;
case "crea un <em>costo aggiuntivo</em>":  	$messaggio = "criar um <em>custo adicional</em>"; break;
case "per il punto vendita":  			$messaggio = "pelo punto de venda"; break;
case "<em>Nome</em> del costo aggiuntivo":  	$messaggio = "<em>Nome</em> do custo adicional"; break;
case "Categoria":  				$messaggio = "Categoria"; break;
case "nuova":  					$messaggio = "novo"; break;
case "esistente":  				$messaggio = "existente"; break;
case "<em>Prezzo</em> del costo aggiuntivo":	$messaggio = "<em>Preço</em> do custo adicional"; break;
case "Costo aggiuntivo non inserito":  		$messaggio = "O custo adicional não foi inserido"; break;
case "costo già esistente":  			$messaggio = "custo já existente"; break;
case "prezzo sbagliato":  			$messaggio = "preço errado"; break;
case "Attenzione":  				$messaggio = "Atenção"; break;
case "esiste già un costo aggiuntivo associato a questo bene in questo magazzino":	$messaggio = "Já existe um custo adicional associado a este bem neste armazém"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.tar.gz: pt/inventario.php <==
<?php

switch ($messaggio) {

case "Inventario":  				$messaggio = "Inventário"; break;
case "Inventario del magazzino":  		$messaggio = "Inventário do armazém"; break;
case "Nome bene":  				$messaggio = "Nome do bem"; break;
case "Quantità minima predefinita":  		$messaggio = "Quantidade mínima padrão"; break;
case "Quantità attuale":  			$messaggio = "Quantidade atual"; break;
case "Nuova quantità":  			$messaggio = "Nova quantidade"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Modifica le quantità attuali":  		$messaggio = "Alterar a quantidade atual"; break;
case "aggiungi":  				$messaggio = "adicionar"; break;
case "cancella":  				$messaggio = "apagar"; break;
case "Bene":  					$messaggio = "Bem"; break;
case "cancellato":  				$messaggio = "apagado"; break;
case "Quantità aggiornate":  			$messaggio = "Quantidade atualizada"; break;
case "Nuovo bene":  				$messaggio = "Novo bem"; break;
case "aggiunto":  				$messaggio = "adicionado"; break;
case "ricarica":  				$messaggio = "recarregar"; break;
case "Si è sicuri di voler eliminare il bene":	$messaggio = "Você tem certeza que quer apagar o bem"; break;
case "dall'inventario":  			$messaggio = "do inventário"; break;
case "del magazzino":  				$messaggio = "do armazém"; break;
case "SI":  					$messaggio = "SIM"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "Bene ricaricato":  			$messaggio = "Bem recarregado"; break;
case "Ricarica il bene":  			$messaggio = "recarregar o bem"; break;
case "da":  					$messaggio = "do"; break;
case "magazzino":  				$messaggio = "armazém"; break;
case "Nessun posto da cui ricaricare":  	$messaggio = "Não há lugar para recarregar"; break;
case "mancanti":  				$messaggio = "em falta"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "richiesto_per registrare entrata":  	$messaggio = "pedido_para registrar a entrada"; break;
case "si":  					$messaggio = "sim"; break;
case "no":  					$messaggio = "não"; break;
case "Aggiungi":  				$messaggio = "Adicionar"; break;
case "Sottrai":  				$messaggio = "Subtrair"; break;
case "crea un <em>costo aggiuntivo</em>":  	$messaggio = "criar um <em>custo adicional</em>"; break;
case "per il punto vendita":  			$messaggio = "pelo punto de venda"; break;
case "<em>Nome</em> del costo aggiuntivo":  	$messaggio = "<em>Nome</em> do custo adicional"; break;
case "Categoria":  				$messaggio = "Categoria"; break;
case "nuova":  					$messaggio = "novo"; break;
case "esistente":  				$messaggio = "existente"; break;
case "<em>Prezzo</em> del costo aggiuntivo":	$messaggio = "<em>Preço</em> do custo adicional"; break;
case "Costo aggiuntivo non inserito":  		$messaggio = "O custo adicional não foi inserido"; break;
case "costo già esistente":  			$messaggio = "custo já existente"; break;
case "prezzo sbagliato":  			$messaggio = "preço errado"; break;
case "Attenzione":  				$messaggio = "Atenção"; break;
case "esiste già un costo aggiuntivo associato a questo bene in questo magazzino":	$messaggio = "Já existe um custo adicional associado a este bem neste armazém"; break;
case "Vai a fondo pagina":  			$messaggio = "Ir para o fim da página"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
